==> hermes-6.0.2.7.tar.gz: hermes-6.0.2.7/app/services/batch_tasks/new_reserved_offer_notification.rb <==
module BatchTasks
  class NewReservedOfferNotification < Base
    MAX_OFFER_PER_NOTIFICATION = 6

    def generate_and_enqueue_notification(date_start: DateTime.now - 1.days, date_end:  DateTime.now, tagset_id: nil, offer_filter: {})
      starttime = Time.now
      @log_name = "#{print_time(starttime)}_new_reserved_offers_from_#{print_time(date_start)}_to_#{print_time(date_end)}.log"
    
      offer_entity_hash = {}

      Hermes::EntityReservation.unscoped.where(is_active: true, last_is_active: date_start .. date_end).pluck(:housing_offer_id, :entity_id).each do |er|
        offer_entity_hash[er.first] ||= []
        offer_entity_hash[er.first] += [er.last]
      end 

      notif_hash = generate_notif_hash(offer_entity_hash, offer_filter)
      notification_nb = enqueue_notifications(notif_hash, :new_reserved_offer)
    
      add_to_log_file("Generated #{notification_nb} notifications in #{(Time.now - starttime).seconds.round(2)}")
    
      create_log_doc(tagset_id)
    end 
    
    private

    def generate_notif_hash(offer_entity_hash, offer_filter)
      notif_hash =  {}

      [
        'seeked',
        'bordering',
        'other_from_department',
      ].each do |type|
        begin
          Hermes::HousingOffer.where(offer_filter.merge(:id.in => offer_entity_hash.keys)).order_by(date_publication_start: :desc).batch_size(1).each do |offer|
            add_to_log_file("Checking #{type} eligibles requests for offer #{offer.id}")
            entity_ids = offer_entity_hash[offer.id]

            eligible_request_ids = offer.eligibles_requests(type).where("$and" => [:entity_id.in => entity_ids], active_application_id: nil).pluck(:id)
            add_to_log_file("Found #{eligible_request_ids.length} eligible requests for offer #{offer.id}")
            eligible_request_ids.each do |request_id|
              notif_hash[request_id] ||= []
              notif_hash[request_id] << offer.id.to_s if notif_hash[request_id].length < MAX_OFFER_PER_NOTIFICATION
            end
          end 
        rescue => exception
          ap exception
          add_to_log_file("housing_offer_id : #{offer.id} => #{exception}")
        end
      end

      notif_hash
    end 
    

  end
end

==> hermes-6.0.2.32.tar.gz: hermes-6.0.2.32/app/services/batch_tasks/new_reserved_offer_notification.rb <==
module BatchTasks
  class NewReservedOfferNotification < Base
    MAX_OFFER_PER_NOTIFICATION = 6

    def generate_and_enqueue_notification(date_start: DateTime.now - 1.days, date_end:  DateTime.now, tagset_id: nil, offer_filter: {})
      starttime = Time.now
      @log_name = "#{print_time(starttime)}_new_reserved_offers_from_#{print_time(date_start)}_to_#{print_time(date_end)}.log"
    
      offer_entity_hash = {}

      Hermes::EntityReservation.unscoped.where(is_active: true, last_is_active: date_start .. date_end).pluck(:housing_offer_id, :entity_id).each do |er|
        offer_entity_hash[er.first] ||= []
        offer_entity_hash[er.first] += [er.last]
      end 

      notif_hash = generate_notif_hash(offer_entity_hash, offer_filter)
      notification_nb = enqueue_notifications(notif_hash, :new_reserved_offer)
    
      add_to_log_file("Generated #{notification_nb} notifications in #{(Time.now - starttime).seconds.round(2)}")
    
      create_log_doc(tagset_id)
    end 
    
    private

    def generate_notif_hash(offer_entity_hash, offer_filter)
      notif_hash =  {}

      [
        'seeked',
        'bordering',
        'other_from_department',
      ].each do |type|
        begin
          Hermes::HousingOffer.where(offer_filter.merge(:id.in => offer_entity_hash.keys)).order_by(date_publication_start: :desc).batch_size(1).each do |offer|
            add_to_log_file("Checking #{type} eligibles requests for offer #{offer.id}")
            entity_ids = offer_entity_hash[offer.id]

            eligible_request_ids = offer.eligibles_requests(type).where("$and" => [:entity_id.in => entity_ids], active_application_id: nil).pluck(:id)
            add_to_log_file("Found #{eligible_request_ids.length} #{type} eligible requests for offer #{offer.id}")
            eligible_request_ids.each do |request_id|
              notif_hash[request_id] ||= []
              notif_hash[request_id] << offer.id.to_s if notif_hash[request_id].length < MAX_OFFER_PER_NOTIFICATION
            end
          end 
        rescue => exception
          ap exception
          add_to_log_file("housing_offer_id : #{offer.id} => #{exception}")
        end
      end

      notif_hash
    end 
    

  end
end
